@@ -14,10 +14,13 @@ from paper [Attention Is All You Need](https://arxiv.org/abs/1706.03762),
 and derivatives and enhancements of it.
 
 * [Multi-head attention](mha.html)
-* [Relative multi-head attention](xl/relative_mha.html)
 * [Transformer Encoder and Decoder Models](models.html)
 * [Fixed positional encoding](positional_encoding.html)
 
+## [Transformer XL](xl/index.html)
+This implements Transformer XL model using
+[relative multi-head attention](xl/relative_mha.html)
+
 ## [GPT Architecture](gpt)
 
 This is an implementation of GPT-2 architecture.
